summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-07-09 02:23:29 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-07-09 02:23:29 +0000
commit12231ef224d4a1f9057b5c3fd9d113aacc664a37 (patch)
tree08d9e338888eb8d5ce3512b5f5836b199f0558f2
parentd646e75cb749634caa560bbfe415e371bb579245 (diff)
downloadlibkdcraw-12231ef2.tar.gz
libkdcraw-12231ef2.zip
Remove the tq in front of these incorrectly TQt4-converted methods/data members:
tqrepaint[...] tqinvalidate[...] tqparent[...] tqmask[...] tqlayout[...] tqalignment[...] git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/libraries/libkdcraw@1240522 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
-rw-r--r--libkdcraw/libraw/internal/dcraw_common.cpp56
-rw-r--r--libkdcraw/libraw/libraw/libraw.h8
-rw-r--r--libkdcraw/libraw/libraw/libraw_types.h10
-rw-r--r--libkdcraw/libraw/samples/unprocessed_raw.cpp4
-rw-r--r--libkdcraw/libraw/src/libraw_c_api.cpp38
-rw-r--r--libkdcraw/libraw/src/libraw_cxx.cpp34
6 files changed, 75 insertions, 75 deletions
diff --git a/libkdcraw/libraw/internal/dcraw_common.cpp b/libkdcraw/libraw/internal/dcraw_common.cpp
index 93d7a37..252b43d 100644
--- a/libkdcraw/libraw/internal/dcraw_common.cpp
+++ b/libkdcraw/libraw/internal/dcraw_common.cpp
@@ -273,7 +273,7 @@ void CLASS canon_600_load_raw()
{
black += pixel[col];
#ifdef LIBRAW_LIBRARY_BUILD
- ushort *dfp = get_tqmasked_pointer(row,col);
+ ushort *dfp = get_masked_pointer(row,col);
if(dfp) *dfp = pixel[col];
#endif
}
@@ -346,7 +346,7 @@ void CLASS canon_a5_load_raw()
buf = (vbits += 16, (buf << 16) + *dp++);
pixel = buf >> vbits & 0x3ff;
#ifdef LIBRAW_LIBRARY_BUILD
- ushort *dfp = get_tqmasked_pointer(row+top_margin,col+left_margin);
+ ushort *dfp = get_masked_pointer(row+top_margin,col+left_margin);
if(dfp) *dfp = pixel;
#endif
if ((unsigned) row < height && (unsigned) col < width)
@@ -619,7 +619,7 @@ void CLASS canon_compressed_load_raw()
#endif
for (col=0; col < raw_width; col++) {
#ifdef LIBRAW_LIBRARY_BUILD
- ushort *dfp = get_tqmasked_pointer(row+r,col);
+ ushort *dfp = get_masked_pointer(row+r,col);
if(dfp) *dfp = pixel[r*raw_width+col];
if (irow >= height) continue; // skip for top/bottom rows
#endif
@@ -771,7 +771,7 @@ void CLASS lossless_jpeg_load_raw()
if (raw_width == 3984 && (col -= 2) < 0)
col += (row--,raw_width);
#ifdef LIBRAW_LIBRARY_BUILD
- ushort *dfp = get_tqmasked_pointer(row,col);
+ ushort *dfp = get_masked_pointer(row,col);
if(dfp) *dfp = val;
#endif
if ((unsigned) (row-top_margin) < height) {
@@ -880,7 +880,7 @@ void CLASS adobe_copy_pixel (int row, int col, ushort **rp)
BAYER(r,c) = val;
else
{
- ushort *dfp = get_tqmasked_pointer(row+top_margin,col+left_margin);
+ ushort *dfp = get_masked_pointer(row+top_margin,col+left_margin);
if(dfp) *dfp = val;
}
#else
@@ -987,7 +987,7 @@ void CLASS pentax_k10_load_raw()
#ifdef LIBRAW_LIBRARY_BUILD
else
{
- ushort *dfp = get_tqmasked_pointer(row,col);
+ ushort *dfp = get_masked_pointer(row,col);
if(dfp) *dfp = hpred[col & 1];
}
@@ -1081,7 +1081,7 @@ void CLASS nikon_compressed_load_raw()
}
else
{
- ushort *dfp = get_tqmasked_pointer(row,col);
+ ushort *dfp = get_masked_pointer(row,col);
if(dfp) *dfp = xval;
}
#endif
@@ -1251,7 +1251,7 @@ void CLASS fuji_load_raw()
}
else
{
- ushort *dfp = get_tqmasked_pointer(row,col);
+ ushort *dfp = get_masked_pointer(row,col);
if(dfp) *dfp = pixel[col];
}
}
@@ -1330,7 +1330,7 @@ void CLASS rollei_load_raw()
#ifdef LIBRAW_LIBRARY_BUILD
else
{
- ushort *dfp = get_tqmasked_pointer(todo[i] / raw_width,todo[i] % raw_width);
+ ushort *dfp = get_masked_pointer(todo[i] / raw_width,todo[i] % raw_width);
if(dfp) *dfp = (todo[i+1] & 0x3ff);
}
#endif
@@ -1553,7 +1553,7 @@ void CLASS phase_one_load_raw()
}
for (col=0; col < raw_width; col++)
{
- ushort *dfp = get_tqmasked_pointer(row,col);
+ ushort *dfp = get_masked_pointer(row,col);
if(dfp)
*dfp = pixel[col];
else
@@ -1608,9 +1608,9 @@ void CLASS phase_one_load_raw_c()
{
read_shorts ((ushort *) t_black[0], raw_height*2);
#ifdef LIBRAW_LIBRARY_BUILD
- imgdata.tqmasked_pixels.ph1_black = (ushort (*)[2])calloc(raw_height*2,sizeof(ushort));
- merror (imgdata.tqmasked_pixels.ph1_black, "phase_one_load_raw_c()");
- memmove(imgdata.tqmasked_pixels.ph1_black,(ushort *) t_black[0],raw_height*2*sizeof(ushort));
+ imgdata.masked_pixels.ph1_black = (ushort (*)[2])calloc(raw_height*2,sizeof(ushort));
+ merror (imgdata.masked_pixels.ph1_black, "phase_one_load_raw_c()");
+ memmove(imgdata.masked_pixels.ph1_black,(ushort *) t_black[0],raw_height*2*sizeof(ushort));
#endif
}
for (i=0; i < 256; i++)
@@ -1662,7 +1662,7 @@ void CLASS phase_one_load_raw_c()
}
else
{
- ushort *dfp = get_tqmasked_pointer(row,col);
+ ushort *dfp = get_masked_pointer(row,col);
if(i>0 && dfp) *dfp = i;
}
}
@@ -1675,7 +1675,7 @@ void CLASS phase_one_load_raw_c()
- ph1.t_black + t_black[row][(col+left_margin) >= ph1.split_col];
if (i > 0)
{
- ushort *dfp = get_tqmasked_pointer(row,col);
+ ushort *dfp = get_masked_pointer(row,col);
if(dfp) *dfp = i;
}
}
@@ -1719,7 +1719,7 @@ void CLASS hasselblad_load_raw()
#ifdef LIBRAW_LIBRARY_BUILD
else
{
- ushort *dfp = get_tqmasked_pointer(row+top_margin,col+left_margin);
+ ushort *dfp = get_masked_pointer(row+top_margin,col+left_margin);
if(dfp) *dfp = pred[i];
}
#endif
@@ -1833,7 +1833,7 @@ void CLASS packed_12_load_raw()
#ifdef LIBRAW_LIBRARY_BUILD
else
{
- ushort *dfp = get_tqmasked_pointer(row,col);
+ ushort *dfp = get_masked_pointer(row,col);
if(dfp) *dfp = bitbuf << (52-vbits) >> 52;
}
#endif
@@ -1871,7 +1871,7 @@ void CLASS unpacked_load_raw()
//fseek (ifp, 2*(raw_width - width), SEEK_CUR);
for (col=0; col < raw_width; col++)
{
- ushort *dfp = get_tqmasked_pointer(row,col);
+ ushort *dfp = get_masked_pointer(row,col);
if(dfp)
*dfp = pixel[col];
else
@@ -1904,7 +1904,7 @@ void CLASS nokia_load_raw()
int col;
for(col=0;col<width;col++)
{
- ushort *dfp = get_tqmasked_pointer(row,col);
+ ushort *dfp = get_masked_pointer(row,col);
if(dfp)
*dfp = pixel[col];
}
@@ -1969,7 +1969,7 @@ void CLASS panasonic_load_raw()
#ifdef LIBRAW_LIBRARY_BUILD
if(col>=width)
{
- ushort *dfp = get_tqmasked_pointer(row,col);
+ ushort *dfp = get_masked_pointer(row,col);
if(dfp)*dfp = pred[col & 1];
}
#endif
@@ -2008,7 +2008,7 @@ void CLASS olympus_e300_load_raw()
#else
for (col=0; col < raw_width; col++)
{
- ushort *dfp = get_tqmasked_pointer(row,col);
+ ushort *dfp = get_masked_pointer(row,col);
if(dfp)
*dfp = (pixel[col] & 0xfff);
else
@@ -2445,14 +2445,14 @@ void CLASS eight_bit_load_raw()
BAYER(row,col-left_margin) = val;
else
{
- ushort *dfp = get_tqmasked_pointer(row,col);
+ ushort *dfp = get_masked_pointer(row,col);
if(dfp) *dfp = val;
lblack += val;
}
}
else // top/bottom margins
{
- ushort *dfp = get_tqmasked_pointer(row,col);
+ ushort *dfp = get_masked_pointer(row,col);
if(dfp) *dfp = val;
}
}
@@ -2547,7 +2547,7 @@ void CLASS kodak_262_load_raw()
black += val;
#else
{
- ushort *dfp = get_tqmasked_pointer(row,col);
+ ushort *dfp = get_masked_pointer(row,col);
if(dfp) *dfp = val;
black += val;
}
@@ -2741,12 +2741,12 @@ void CLASS sony_load_raw()
#ifdef LIBRAW_LIBRARY_BUILD
for (col=0; col < left_margin; col++)
{
- ushort *dfp = get_tqmasked_pointer(row,col);
+ ushort *dfp = get_masked_pointer(row,col);
if(dfp) *dfp = ntohs(pixel[col]);
}
for (col=left_margin+width; col < raw_width; col++)
{
- ushort *dfp = get_tqmasked_pointer(row,col);
+ ushort *dfp = get_masked_pointer(row,col);
if(dfp) *dfp = ntohs(pixel[col]);
}
#endif
@@ -2782,7 +2782,7 @@ void CLASS sony_arw_load_raw()
#ifdef LIBRAW_LIBRARY_BUILD
else
{
- ushort *dfp = get_tqmasked_pointer(row,col);
+ ushort *dfp = get_masked_pointer(row,col);
if(dfp) *dfp = sum;
}
#endif
@@ -2903,7 +2903,7 @@ void CLASS smal_decode_segment (unsigned seg[2][2], int holes)
#ifdef LIBRAW_LIBRARY_BUILD
else
{
- ushort *dfp = get_tqmasked_pointer(row+top_margin,col+left_margin);
+ ushort *dfp = get_masked_pointer(row+top_margin,col+left_margin);
if(dfp) *dfp = pred[pix &1];
}
#endif
diff --git a/libkdcraw/libraw/libraw/libraw.h b/libkdcraw/libraw/libraw/libraw.h
index e9fcee1..a9c486d 100644
--- a/libkdcraw/libraw/libraw/libraw.h
+++ b/libkdcraw/libraw/libraw/libraw.h
@@ -62,7 +62,7 @@ DllDef int libraw_cameraCount();
DllDef void libraw_set_memerror_handler(libraw_data_t*, memory_callback cb, void *datap);
DllDef void libraw_set_dataerror_handler(libraw_data_t*,data_callback func,void *datap);
DllDef void libraw_set_progress_handler(libraw_data_t*,progress_callback cb,void *datap);
-DllDef int libraw_add_tqmasked_borders_to_bitmap(libraw_data_t* lr);
+DllDef int libraw_add_masked_borders_to_bitmap(libraw_data_t* lr);
DllDef const char * libraw_unpack_function_name(libraw_data_t* lr);
DllDef int libraw_rotate_fuji_raw(libraw_data_t* lr);
@@ -124,7 +124,7 @@ class DllDef LibRaw
int FC(int row,int col) { return (imgdata.idata.filters >> ((((row) << 1 & 14) + ((col) & 1)) << 1) & 3);}
int fc (int row, int col);
- int add_tqmasked_borders_to_bitmap();
+ int add_masked_borders_to_bitmap();
const char *unpack_function_name();
int rotate_fuji_raw();
@@ -157,8 +157,8 @@ class DllDef LibRaw
// moved from implementation level to private: visibility
- void init_tqmasked_ptrs();
- ushort *get_tqmasked_pointer(int row, int col);
+ void init_masked_ptrs();
+ ushort *get_masked_pointer(int row, int col);
int own_filtering_supported(){ return 0;}
void identify();
diff --git a/libkdcraw/libraw/src/libraw_c_api.cpp b/libkdcraw/libraw/src/libraw_c_api.cpp
index ac3957b..8ce5736 100644
--- a/libkdcraw/libraw/src/libraw_c_api.cpp
+++ b/libkdcraw/libraw/src/libraw_c_api.cpp
@@ -27,78 +27,78 @@ extern "C"
const char* libraw_unpack_function_name(libraw_data_t* lr)
{
if(!lr) return "NULL parameter passed";
- LibRaw *ip = (LibRaw*) lr->tqparent_class;
+ LibRaw *ip = (LibRaw*) lr->parent_class;
return ip->unpack_function_name();
}
int libraw_rotate_fuji_raw(libraw_data_t* lr)
{
if(!lr) return EINVAL;
- LibRaw *ip = (LibRaw*) lr->tqparent_class;
+ LibRaw *ip = (LibRaw*) lr->parent_class;
return ip->rotate_fuji_raw();
}
- int libraw_add_tqmasked_borders_to_bitmap(libraw_data_t* lr)
+ int libraw_add_masked_borders_to_bitmap(libraw_data_t* lr)
{
if(!lr) return EINVAL;
- LibRaw *ip = (LibRaw*) lr->tqparent_class;
- return ip->add_tqmasked_borders_to_bitmap();
+ LibRaw *ip = (LibRaw*) lr->parent_class;
+ return ip->add_masked_borders_to_bitmap();
}
int libraw_open_file(libraw_data_t* lr, const char *file)
{
if(!lr) return EINVAL;
- LibRaw *ip = (LibRaw*) lr->tqparent_class;
+ LibRaw *ip = (LibRaw*) lr->parent_class;
return ip->open_file(file);
}
int libraw_open_buffer(libraw_data_t* lr, void *buffer, size_t size)
{
if(!lr) return EINVAL;
- LibRaw *ip = (LibRaw*) lr->tqparent_class;
+ LibRaw *ip = (LibRaw*) lr->parent_class;
return ip->open_buffer(buffer,size);
}
int libraw_unpack(libraw_data_t* lr)
{
if(!lr) return EINVAL;
- LibRaw *ip = (LibRaw*) lr->tqparent_class;
+ LibRaw *ip = (LibRaw*) lr->parent_class;
return ip->unpack();
}
int libraw_unpack_thumb(libraw_data_t* lr)
{
if(!lr) return EINVAL;
- LibRaw *ip = (LibRaw*) lr->tqparent_class;
+ LibRaw *ip = (LibRaw*) lr->parent_class;
return ip->unpack_thumb();
}
void libraw_recycle(libraw_data_t* lr)
{
if(!lr) return;
- LibRaw *ip = (LibRaw*) lr->tqparent_class;
+ LibRaw *ip = (LibRaw*) lr->parent_class;
ip->recycle();
}
void libraw_close(libraw_data_t* lr)
{
if(!lr) return;
- LibRaw *ip = (LibRaw*) lr->tqparent_class;
+ LibRaw *ip = (LibRaw*) lr->parent_class;
delete ip;
}
void libraw_set_memerror_handler(libraw_data_t* lr, memory_callback cb,void *data)
{
if(!lr) return;
- LibRaw *ip = (LibRaw*) lr->tqparent_class;
+ LibRaw *ip = (LibRaw*) lr->parent_class;
ip->set_memerror_handler(cb,data);
}
void libraw_set_dataerror_handler(libraw_data_t* lr,data_callback func,void *data)
{
if(!lr) return;
- LibRaw *ip = (LibRaw*) lr->tqparent_class;
+ LibRaw *ip = (LibRaw*) lr->parent_class;
ip->set_dataerror_handler(func,data);
}
void libraw_set_progress_handler(libraw_data_t* lr, progress_callback cb,void *data)
{
if(!lr) return;
- LibRaw *ip = (LibRaw*) lr->tqparent_class;
+ LibRaw *ip = (LibRaw*) lr->parent_class;
ip->set_progress_handler(cb,data);
}
@@ -107,34 +107,34 @@ extern "C"
int libraw_adjust_sizes_info_only(libraw_data_t* lr)
{
if(!lr) return EINVAL;
- LibRaw *ip = (LibRaw*) lr->tqparent_class;
+ LibRaw *ip = (LibRaw*) lr->parent_class;
return ip->adjust_sizes_info_only();
}
int libraw_dcraw_document_mode_processing(libraw_data_t* lr)
{
if(!lr) return EINVAL;
- LibRaw *ip = (LibRaw*) lr->tqparent_class;
+ LibRaw *ip = (LibRaw*) lr->parent_class;
return ip->dcraw_document_mode_processing();
}
int libraw_dcraw_ppm_tiff_writer(libraw_data_t* lr,const char *filename)
{
if(!lr) return EINVAL;
- LibRaw *ip = (LibRaw*) lr->tqparent_class;
+ LibRaw *ip = (LibRaw*) lr->parent_class;
return ip->dcraw_ppm_tiff_writer(filename);
}
int libraw_dcraw_thumb_writer(libraw_data_t* lr,const char *fname)
{
if(!lr) return EINVAL;
- LibRaw *ip = (LibRaw*) lr->tqparent_class;
+ LibRaw *ip = (LibRaw*) lr->parent_class;
return ip->dcraw_thumb_writer(fname);
}
int libraw_dcraw_process(libraw_data_t* lr)
{
if(!lr) return EINVAL;
- LibRaw *ip = (LibRaw*) lr->tqparent_class;
+ LibRaw *ip = (LibRaw*) lr->parent_class;
return ip->dcraw_process();
}
diff --git a/libkdcraw/libraw/src/libraw_cxx.cpp b/libkdcraw/libraw/src/libraw_cxx.cpp
index f7fe84d..be1ec0a 100644
--- a/libkdcraw/libraw/src/libraw_cxx.cpp
+++ b/libkdcraw/libraw/src/libraw_cxx.cpp
@@ -53,7 +53,7 @@ extern "C"
case LIBRAW_UNSUPPORTED_THUMBNAIL:
return "Unsupported thumbnail format";
case LIBRAW_CANNOT_ADDMASK:
- return "Cannot add tqmasked pixels to resized image";
+ return "Cannot add masked pixels to resized image";
case LIBRAW_UNSUFFICIENT_MEMORY:
return "Unsufficient memory";
case LIBRAW_DATA_ERROR:
@@ -85,7 +85,7 @@ const float LibRaw_constants::d65_white[3] = { 0.950456, 1, 1.088754 };
#define S imgdata.sizes
#define O imgdata.params
#define C imgdata.color
-#define M imgdata.tqmasked_pixels
+#define M imgdata.masked_pixels
#define T imgdata.thumbnail
#define IO libraw_internal_data.internal_output_params
#define ID libraw_internal_data.internal_data
@@ -162,7 +162,7 @@ LibRaw:: LibRaw(unsigned int flags)
imgdata.params.output_bps=8;
imgdata.params.use_fuji_rotate=1;
imgdata.params.auto_bright_thr = 0.01;
- imgdata.tqparent_class = this;
+ imgdata.parent_class = this;
imgdata.progress_flags = 0;
tls = new LibRaw_TLS;
tls->init();
@@ -225,11 +225,11 @@ void LibRaw:: recycle()
FREE(libraw_internal_data.output_data.histogram);
FREE(libraw_internal_data.output_data.oprof);
FREE(imgdata.color.profile);
- FREE(imgdata.tqmasked_pixels.buffer);
- FREE(imgdata.tqmasked_pixels.ph1_black);
+ FREE(imgdata.masked_pixels.buffer);
+ FREE(imgdata.masked_pixels.ph1_black);
#undef FREE
#define ZERO(a) bzero(&a,sizeof(a))
- ZERO(imgdata.tqmasked_pixels);
+ ZERO(imgdata.masked_pixels);
ZERO(imgdata.sizes);
ZERO(libraw_internal_data.internal_output_params);
#undef ZERO
@@ -316,7 +316,7 @@ void LibRaw:: merror (void *ptr, const char *where)
throw LIBRAW_EXCEPTION_ALLOC;
}
-ushort * LibRaw::get_tqmasked_pointer(int row, int col)
+ushort * LibRaw::get_masked_pointer(int row, int col)
{
if(row<0 || col < 0) return NULL;
if(!M.buffer) return NULL;
@@ -391,7 +391,7 @@ ushort * LibRaw::get_tqmasked_pointer(int row, int col)
return NULL;
}
-void LibRaw:: init_tqmasked_ptrs()
+void LibRaw:: init_masked_ptrs()
{
if(!M.buffer) return;
@@ -411,7 +411,7 @@ void LibRaw:: init_tqmasked_ptrs()
}
-int LibRaw::add_tqmasked_borders_to_bitmap()
+int LibRaw::add_masked_borders_to_bitmap()
{
CHECK_ORDER_HIGH(LIBRAW_PROGRESS_PRE_INTERPOLATE);
CHECK_ORDER_LOW(LIBRAW_PROGRESS_LOAD_RAW);
@@ -434,14 +434,14 @@ int LibRaw::add_tqmasked_borders_to_bitmap()
ushort (*newimage)[4];
newimage = (ushort (*)[4]) calloc (S.raw_height*S.raw_width, sizeof (*newimage));
- merror (newimage, "add_tqmasked_borders_to_bitmap()");
+ merror (newimage, "add_masked_borders_to_bitmap()");
int r,c;
// top rows
for (r=0; r<S.top_margin;r++)
for(c=0;c<S.raw_width;c++)
{
- ushort *p = get_tqmasked_pointer(r,c);
+ ushort *p = get_masked_pointer(r,c);
if(p)
newimage[r*S.raw_width+c][FC(r,c)] = *p;
}
@@ -451,7 +451,7 @@ int LibRaw::add_tqmasked_borders_to_bitmap()
int row = r-S.top_margin;
for(c=0;c<S.left_margin;c++)
{
- ushort *p = get_tqmasked_pointer(r,c);
+ ushort *p = get_masked_pointer(r,c);
if(p)
newimage[r*S.raw_width+c][FC(r,c)] = *p;
}
@@ -462,7 +462,7 @@ int LibRaw::add_tqmasked_borders_to_bitmap()
}
for(c=S.left_margin+S.iwidth;c<S.raw_width;c++)
{
- ushort *p = get_tqmasked_pointer(r,c);
+ ushort *p = get_masked_pointer(r,c);
if(p)
newimage[r*S.raw_width+c][FC(r,c)] = *p;
}
@@ -471,7 +471,7 @@ int LibRaw::add_tqmasked_borders_to_bitmap()
for (r=S.top_margin+S.height; r<S.raw_height;r++)
for(c=0;c<S.raw_width;c++)
{
- ushort *p = get_tqmasked_pointer(r,c);
+ ushort *p = get_masked_pointer(r,c);
if(p)
newimage[r*S.raw_width+c][FC(r,c)] = *p;
}
@@ -656,9 +656,9 @@ int LibRaw::unpack(void)
{
unsigned sz = S.raw_height*(S.left_margin+S.right_margin)
+ S.width*(S.top_margin+S.bottom_margin);
- imgdata.tqmasked_pixels.buffer = (ushort*) calloc(sz, sizeof(ushort));
- merror (imgdata.tqmasked_pixels.buffer, "unpack()");
- init_tqmasked_ptrs();
+ imgdata.masked_pixels.buffer = (ushort*) calloc(sz, sizeof(ushort));
+ merror (imgdata.masked_pixels.buffer, "unpack()");
+ init_masked_ptrs();
}
if (libraw_internal_data.unpacker_data.meta_length)
{
diff --git a/libkdcraw/libraw/libraw/libraw_types.h b/libkdcraw/libraw/libraw/libraw_types.h
index f0075a7..a39fceb 100644
--- a/libkdcraw/libraw/libraw/libraw_types.h
+++ b/libkdcraw/libraw/libraw/libraw_types.h
@@ -140,8 +140,8 @@ typedef struct
double pixel_aspect;
int flip;
- // tqmasked border sizes
- ushort right_margin,bottom_margin; // right tqmasked width and bottom height, inited after idendify()
+ // masked border sizes
+ ushort right_margin,bottom_margin; // right masked width and bottom height, inited after idendify()
} libraw_image_sizes_t;
@@ -264,7 +264,7 @@ typedef struct
ushort *bottom; // bottom size=(raw_height-height-top_margin)*width
ushort *br; // bottom right size=(raw_height-height-top_margin)*
ushort (*ph1_black)[2]; // Phase One black
-}libraw_tqmasked_t;
+}libraw_masked_t;
typedef struct
{
@@ -275,14 +275,14 @@ typedef struct
libraw_colordata_t color;
libraw_imgother_t other;
libraw_thumbnail_t thumbnail;
- libraw_tqmasked_t tqmasked_pixels;
+ libraw_masked_t masked_pixels;
ushort (*image)[4] ;
#ifdef _OPENMP
#pragma omp shared(image)
#endif
libraw_output_params_t params;
// pointer to LibRaw class for use in C calls
- void *tqparent_class;
+ void *parent_class;
} libraw_data_t;
diff --git a/libkdcraw/libraw/samples/unprocessed_raw.cpp b/libkdcraw/libraw/samples/unprocessed_raw.cpp
index 6910fcf..5599509 100644
--- a/libkdcraw/libraw/samples/unprocessed_raw.cpp
+++ b/libkdcraw/libraw/samples/unprocessed_raw.cpp
@@ -4,7 +4,7 @@
* Created: Fri Jan 02, 2009
*
* LibRaw sample
* Generates unprocessed raw image: with tqmasked pixels and without black subtraction
*
* This program is free software; you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
@@ -116,7 +116,7 @@ int main(int ac, char *av[])
if(verbose)
printf("Unpacked....\n");
- if( (ret = RawProcessor.add_tqmasked_borders_to_bitmap() ) != LIBRAW_SUCCESS)
+ if( (ret = RawProcessor.add_masked_borders_to_bitmap() ) != LIBRAW_SUCCESS)
{
fprintf(stderr,"Cannot add tqmask data to bitmap %s\n",av[i]);
}
@@ -4,7 +4,7 @@
*
* LibRaw sample
- * Generates unprocessed raw image: with tqmasked pixels and without black subtraction
+ * Generates unprocessed raw image: with masked pixels and without black subtraction
*
* This program is free software; you can redistribute it and/or modify